Crate iced_runtime

Crate iced_runtime 

A renderer-agnostic native GUI runtime.

The native path of the Iced ecosystem

iced_runtime takes iced_core and builds a native runtime on top of it.

Re-exports

pub use task::Task;
pub use user_interface::UserInterface;
pub use window::Window;
pub use iced_core as core;
pub use iced_futures as futures;

Modules

clipboard
Access the clipboard.
font
Load and use fonts.
image
Allocate images explicitly to control presentation.
keyboard
Track keyboard events and handle keyboard navigation.
system
Access the native system.
task
Create runtime tasks.
user_interface
Implement your own event loop to drive a user interface.
widget
Operate on widgets and query them at runtime.
window
Build window-based GUI applications.

Enums

Action
An action that the iced runtime can perform.

Functions

exit
Creates a Task that exits the iced runtime.