Module font

Module font 

Load and use fonts.

Enums

Action
A font action.

Functions

list
Lists all the available font families in the system.
load
Load a font from its bytes.
set_defaults
Sets a new default Font and text size for the running application.