handle_ctrl_tab

Function handle_ctrl_tab 

pub fn handle_ctrl_tab<Message, Theme, Renderer>(
    event: &Event,
    ui: &mut UserInterface<'_, Message, Theme, Renderer>,
    renderer: &Renderer,
) -> bool
where Renderer: Renderer,
Handle Ctrl+Tab / Ctrl+Shift+Tab for unconditional focus navigation.

This always moves focus regardless of whether any widget captured the event. It is the emergency exit from any focus trap.

Returns true if the event was consumed.